
## CATO-CLI - mutation.site.removeCloudInterconnectPhysicalConnection:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeCloudInterconnectPhysicalConnection) for documentation on this operation.

### Usage for mutation.site.removeCloudInterconnectPhysicalConnection:

`catocli mutation site removeCloudInterconnectPhysicalConnection -h`

`catocli mutation site removeCloudInterconnectPhysicalConnection <json>`

`catocli mutation site removeCloudInterconnectPhysicalConnection "$(cat < mutation.site.removeCloudInterconnectPhysicalConnection.json)"`

`catocli mutation site removeCloudInterconnectPhysicalConnection '{"removeCloudInterconnectPhysicalConnectionInput":{"id":"id"}}'`

`catocli mutation site removeCloudInterconnectPhysicalConnection -p '{
    "removeCloudInterconnectPhysicalConnectionInput": {
        "id": "id"
    }
}'`


#### Operation Arguments for mutation.site.removeCloudInterconnectPhysicalConnection ####

`accountId` [ID] - (required) N/A    
`removeCloudInterconnectPhysicalConnectionInput` [RemoveCloudInterconnectPhysicalConnectionInput] - (required) N/A    
